=======
Credits
=======

Development Lead
----------------

* Adam Johnson <me@adamj.eu>

Original Author
---------------

Originally created by Ben Davis at https://github.com/ben-davis/prettycron .

Contributors
------------

None yet. Why not be the first?
